# 📦 SOMOs – Module import summary

| Module | Type | Add to `pyproject.toml`? |
|--------|------|---------------------------|
| `os` | Standard Library | ❌ No |
| `sys` | Standard Library | ❌ No |
| `platform` | Standard Library | ❌ No |
| `re` | Standard Library | ❌ No |
| `time` | Standard Library | ❌ No |
| `datetime` | Standard Library | ❌ No |
| `math` | Standard Library | ❌ No |
| `pathlib` | Standard Library | ❌ No |
| `tempfile` | Standard Library | ❌ No |
| `shutil` | Standard Library | ❌ No |
| `itertools` | Standard Library | ❌ No |
| `functools` | Standard Library | ❌ No |
| `urllib.request` | Standard Library | ❌ No |
| `numpy` | External | ✅ Yes |
| `pandas` | External | ✅ Yes |
| `matplotlib` | External | ✅ Yes |
| `seaborn` | External | ✅ Yes |
| `scipy` | External | ✅ Yes |
| `scikit-learn` | External | ✅ Yes |
| `cclib` | External | ✅ Yes |
| `ipywidgets` | External | ✅ Yes |
| `IPython.display` | External | ✅ Yes |
| `openpyxl` | External | ✅ Yes |
| `plotly` | External | ✅ Yes |
| `tools4pyPC` | Local module | ❌ No |
| `tools4AS` | Local module | ❌ No |
| `visualID_Eng` | Local module | ❌ No |
